from test.python import TEST_DATA_FOLDER

CURRENT_TEST_DATA_FOLDER = TEST_DATA_FOLDER / 'inspectors'

PYTHON_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'python'

JAVA_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'java'

KOTLIN_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'kotlin'

SPRING_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'spring'

JS_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'js'

PYTHON_AST_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'python_ast'

CHECKSTYLE_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'checkstyle'

PMD_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'pmd'

FLAKE_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'flake8'

PYLINT_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'pylint'

DETEKT_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'detekt'

ESLINT_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'eslint'
